module.exports = defineTest({
	description: 'supports class fields'
});
